@@ -607,54 +607,3 @@ BrokerError err = AW_NO_ERROR;
 
 	return ( err );
 }
-
-
-
-BrokerError
-awxsSetEventFromTypedHash ( BrokerEvent event, HV * data, HV * type )
-{
-int i, n;
-HE* entry;
-SV* value;
-SV** ssv;
-char * key;
-short field_type;
-BrokerError err = AW_NO_ERROR;
-
-
-
-#if    AWXS_DEBUG
-	printf ( "        Hello from setEventFromTypedHash \n" );
-#endif /* DEBUG */
-
-
-	n = hv_iterinit ( data );
-
-
-	for ( i=0; i<n; i++ )
-	  {
-		entry = hv_iternext ( data );
-		key   = HeKEY ( entry );
-		value = HeVAL ( entry );
-		ssv = hv_fetch ( type, key, strlen(key), 0 );
-		field_type = (short)SvIV( *ssv );
-		
-		if ( field_type == FIELD_TYPE_SEQUENCE )
-			err = awxsSetSequenceField ( event, key, field_type, 0, 0, (AV*)SvRV(value), NULL, NULL );
-		else
-			{
-			if ( value == NULL )
-				warn ( "      >>Field Value is NULL %s\n", key );
-			else
-				err = awxsSetField ( event, key, field_type, value, NULL, NULL );
-			}
-
-	  }
-
-
-#if    AWXS_DEBUG
-	printf ( "        GoodBye from setEventFromTypedHash\n" );
-#endif /* DEBUG */
-
-	return ( err );
-}
